@@ -19,11 +19,15 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef _ALVABRL_H
-#define _ALVABRL_H
+#ifndef __ALVABRL_H__
+#define __ALVABRL_H__
 
+#include <glib.h>
 #include "braille.h"
 
-int alva_brl_open_device (char* DeviceName, short Port, BRL_DEV_CALLBACK DeviceCallback, BRL_DEVICE *Device);
+gint alva_brl_open_device (gchar          *device_name, 
+			  gshort          port,
+			  BRLDevCallback  device_callback, 
+			  BRLDevice       *device);
 
 #endif
