@@ -44,23 +44,17 @@
 #define DEFAULT_BRLMON_PORT			7000
 #define DEFAULT_REMOTE_PORT			7096
 /*____________________________< BRAILLE_DEFAULTS>___________________________*/
-#define MIN_SERIAL_PORT_NO			1
-#define MAX_SERIAL_PORT_NO			4
-
-#define MIN_TTY_CONSOL_NO			1
-#define MAX_TTY_CONSOL_NO			10
-
-#define MIN_BRAILLE_PORT 			1
-#define MAX_BRAILLE_PORT 			10
+#define MIN_SERIAL_PORT_NO			-1
+#define MAX_SERIAL_PORT_NO			3
 
 #define DEFAULT_BRAILLE_ATTRIBUTES		8
 #define DEFAULT_BRAILLE_STYLE 			"8"
 #define DEFAULT_BRAILLE_CURSOR_STYLE		"underline"
 #define DEFAULT_BRAILLE_TRANSLATION 		"de"
-#define DEFAULT_BRAILLE_DEVICE 			"VARIO20"
+#define DEFAULT_BRAILLE_DEVICE 			"BRLTTY"
 #define DEFAULT_BRAILLE_DEVICE_INDEX 		0
 #define DEFAULT_BRAILLE_DEVICE_COUNT		0
-#define DEFAULT_BRAILLE_PORT_NO 		1
+#define DEFAULT_BRAILLE_PORT_NO 		-1
 #define DEFAULT_BRAILLE_FILL_CHAR 		"##"
 #define DEFAULT_BRAILLE_STATUS_CELL 		"CursorPos"
 #define DEFAULT_BRAILLE_OPTICAL_SENSOR 		0
